@@ -63,7 +63,7 @@ class CorpsEval(Corps):
         해당 코드의 c106의 값이 nan인 경우는 빈딕셔너리로 반환한다.
         """
         d = super().find_c106(period, title)
-        if numpy.isnan(float(list(d.items())[0][1])):
+        if len(d) == 0 or numpy.isnan(float(list(d.items())[0][1])):
             return {}
         else:
             return d
